summaryrefslogtreecommitdiff
path: root/sw/source/ui/dialog/swdlgfact.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/ui/dialog/swdlgfact.hxx')
-rw-r--r--sw/source/ui/dialog/swdlgfact.hxx112
1 files changed, 56 insertions, 56 deletions
diff --git a/sw/source/ui/dialog/swdlgfact.hxx b/sw/source/ui/dialog/swdlgfact.hxx
index c8c19d5bcc0b..5ffd7fcd74ad 100644
--- a/sw/source/ui/dialog/swdlgfact.hxx
+++ b/sw/source/ui/dialog/swdlgfact.hxx
@@ -64,7 +64,7 @@ public: \
{} \
virtual ~Class(); \
virtual short Execute() ;
// virtual void Show( BOOL bVisible = TRUE, USHORT nFlags = 0 )
#define IMPL_ABSTDLG_BASE(Class) \
Class::~Class() \
@@ -87,8 +87,8 @@ class AbstractSwWordCountDialog_Impl : public AbstractSwWordCountDialog
class AbstractSwInsertAbstractDlg_Impl : public AbstractSwInsertAbstractDlg
{
DECL_ABSTDLG_BASE(AbstractSwInsertAbstractDlg_Impl,SwInsertAbstractDlg)
- virtual BYTE GetLevel() const ;
- virtual BYTE GetPara() const ;
+ virtual sal_uInt8 GetLevel() const ;
+ virtual sal_uInt8 GetPara() const ;
};
//add for SwInsertAbstractDlg end
@@ -125,8 +125,8 @@ class AbstractSwBreakDlg_Impl : public AbstractSwBreakDlg // add for SwBreakDlg
{
DECL_ABSTDLG_BASE(AbstractSwBreakDlg_Impl,SwBreakDlg)
virtual String GetTemplateName();
- virtual USHORT GetKind();
- virtual USHORT GetPageNumber();
+ virtual sal_uInt16 GetKind();
+ virtual sal_uInt16 GetPageNumber();
};
class AbstractSplitTableDialog_Impl : public AbstractSplitTableDialog // add for
@@ -141,9 +141,9 @@ class AbstractSplitTableDialog_Impl : public AbstractSplitTableDialog // add for
class AbstractTabDialog_Impl : public SfxAbstractTabDialog
{
DECL_ABSTDLG_BASE( AbstractTabDialog_Impl,SfxTabDialog )
- virtual void SetCurPageId( USHORT nId );
+ virtual void SetCurPageId( sal_uInt16 nId );
virtual const SfxItemSet* GetOutputItemSet() const;
- virtual const USHORT* GetInputRanges( const SfxItemPool& pItem );
+ virtual const sal_uInt16* GetInputRanges( const SfxItemPool& pItem );
virtual void SetInputSet( const SfxItemSet* pInSet );
//From class Window.
virtual void SetText( const XubString& rStr );
@@ -175,7 +175,7 @@ class AbstractSwInsertDBColAutoPilot_Impl : public AbstractSwInsertDBColAutoPil
class AbstractDropDownFieldDialog_Impl : public AbstractDropDownFieldDialog //add for DropDownFieldDialog
{
DECL_ABSTDLG_BASE(AbstractDropDownFieldDialog_Impl, sw::DropDownFieldDialog)
- virtual ByteString GetWindowState( ULONG nMask = WINDOWSTATE_MASK_ALL ) const; //this method inherit from SystemWindow
+ virtual ByteString GetWindowState( sal_uLong nMask = WINDOWSTATE_MASK_ALL ) const; //this method inherit from SystemWindow
virtual void SetWindowState( const ByteString& rStr );//this method inherit from SystemWindow
};
//add for DropDownFieldDialog end
@@ -184,9 +184,9 @@ class AbstractDropDownFieldDialog_Impl : public AbstractDropDownFieldDialog //ad
class AbstarctSwLabDlg_Impl : public AbstarctSwLabDlg
{
DECL_ABSTDLG_BASE(AbstarctSwLabDlg_Impl,SwLabDlg)
- virtual void SetCurPageId( USHORT nId );
+ virtual void SetCurPageId( sal_uInt16 nId );
virtual const SfxItemSet* GetOutputItemSet() const;
- virtual const USHORT* GetInputRanges( const SfxItemPool& pItem );
+ virtual const sal_uInt16* GetInputRanges( const SfxItemPool& pItem );
virtual void SetInputSet( const SfxItemSet* pInSet );
//From class Window.
virtual void SetText( const XubString& rStr );
@@ -201,8 +201,8 @@ class AbstarctSwSelGlossaryDlg_Impl : public AbstarctSwSelGlossaryDlg
{
DECL_ABSTDLG_BASE(AbstarctSwSelGlossaryDlg_Impl,SwSelGlossaryDlg)
virtual void InsertGlos(const String &rRegion, const String &rGlosName); // inline
- virtual USHORT GetSelectedIdx() const; // inline
- virtual void SelectEntryPos(USHORT nIdx); // inline
+ virtual sal_uInt16 GetSelectedIdx() const; // inline
+ virtual void SelectEntryPos(sal_uInt16 nIdx); // inline
};
//add for SwSelGlossaryDlg end
@@ -219,15 +219,15 @@ class AbstractSwAutoFormatDlg_Impl : public AbstractSwAutoFormatDlg
class AbstractSwFldDlg_Impl : public AbstractSwFldDlg //add for SwFldDlg
{
DECL_ABSTDLG_BASE(AbstractSwFldDlg_Impl,SwFldDlg )
- virtual void SetCurPageId( USHORT nId );
+ virtual void SetCurPageId( sal_uInt16 nId );
virtual const SfxItemSet* GetOutputItemSet() const;
- virtual const USHORT* GetInputRanges( const SfxItemPool& pItem );
+ virtual const sal_uInt16* GetInputRanges( const SfxItemPool& pItem );
virtual void SetInputSet( const SfxItemSet* pInSet );
//From class Window.
virtual void SetText( const XubString& rStr );
virtual String GetText() const;
- virtual void Start( BOOL bShow = TRUE ); //this method from SfxTabDialog
- virtual void ShowPage( USHORT nId );// this method from SfxTabDialog
+ virtual void Start( sal_Bool bShow = sal_True ); //this method from SfxTabDialog
+ virtual void ShowPage( sal_uInt16 nId );// this method from SfxTabDialog
virtual void Initialize(SfxChildWinInfo *pInfo);
virtual void ReInitDlg();
virtual void ActivateDatabasePage();
@@ -249,7 +249,7 @@ class AbstractSwRenameXNamedDlg_Impl : public AbstractSwRenameXNamedDlg
class AbstractSwModalRedlineAcceptDlg_Impl : public AbstractSwModalRedlineAcceptDlg
{
DECL_ABSTDLG_BASE(AbstractSwModalRedlineAcceptDlg_Impl,SwModalRedlineAcceptDlg )
- virtual void AcceptAll( BOOL bAccept );
+ virtual void AcceptAll( sal_Bool bAccept );
};
//add for SwModalRedlineAcceptDlg end
@@ -270,7 +270,7 @@ class AbstractFldInputDlg_Impl : public AbstractFldInputDlg
DECL_ABSTDLG_BASE(AbstractFldInputDlg_Impl,SwFldInputDlg)
//from class SalFrame
virtual void SetWindowState( const ByteString& rStr ) ;
- virtual ByteString GetWindowState( ULONG nMask = WINDOWSTATE_MASK_ALL ) const ;
+ virtual ByteString GetWindowState( sal_uLong nMask = WINDOWSTATE_MASK_ALL ) const ;
};
//for SwFldInputDlg end
@@ -280,7 +280,7 @@ class AbstractInsFootNoteDlg_Impl : public AbstractInsFootNoteDlg
{
DECL_ABSTDLG_BASE(AbstractInsFootNoteDlg_Impl,SwInsFootNoteDlg)
virtual String GetFontName();
- virtual BOOL IsEndNote();
+ virtual sal_Bool IsEndNote();
virtual String GetStr();
//from class Window
virtual void SetHelpId( const rtl::OString& sHelpId );
@@ -294,8 +294,8 @@ class AbstractInsertGrfRulerDlg_Impl : public AbstractInsertGrfRulerDlg
{
DECL_ABSTDLG_BASE(AbstractInsertGrfRulerDlg_Impl,SwInsertGrfRulerDlg)
virtual String GetGraphicName();
- virtual BOOL IsSimpleLine();
- virtual BOOL HasImages() const ;
+ virtual sal_Bool IsSimpleLine();
+ virtual sal_Bool HasImages() const ;
};
//for SwInsertGrfRulerDlg end
@@ -304,7 +304,7 @@ class SwInsTableDlg;
class AbstractInsTableDlg_Impl : public AbstractInsTableDlg
{
DECL_ABSTDLG_BASE(AbstractInsTableDlg_Impl,SwInsTableDlg)
- virtual void GetValues( String& rName, USHORT& rRow, USHORT& rCol,
+ virtual void GetValues( String& rName, sal_uInt16& rRow, sal_uInt16& rCol,
SwInsertTableOptions& rInsTblFlags, String& rTableAutoFmtName,
SwTableAutoFmt *& prTAFmt );
};
@@ -317,9 +317,9 @@ class AbstractJavaEditDialog_Impl : public AbstractJavaEditDialog
DECL_ABSTDLG_BASE(AbstractJavaEditDialog_Impl,SwJavaEditDialog)
virtual String GetText();
virtual String GetType();
- virtual BOOL IsUrl();
- virtual BOOL IsNew();
- virtual BOOL IsUpdate();
+ virtual sal_Bool IsUrl();
+ virtual sal_Bool IsNew();
+ virtual sal_Bool IsUpdate();
};
//for SwJavaEditDialog end
@@ -328,7 +328,7 @@ class SwMailMergeDlg;
class AbstractMailMergeDlg_Impl : public AbstractMailMergeDlg
{
DECL_ABSTDLG_BASE(AbstractMailMergeDlg_Impl,SwMailMergeDlg)
- virtual USHORT GetMergeType() ;
+ virtual sal_uInt16 GetMergeType() ;
virtual const ::rtl::OUString& GetSaveFilter() const;
virtual const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any > GetSelection() const ;
virtual ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XResultSet> GetResultSet() const;
@@ -339,7 +339,7 @@ class SwMailMergeCreateFromDlg;
class AbstractMailMergeCreateFromDlg_Impl : public AbstractMailMergeCreateFromDlg
{
DECL_ABSTDLG_BASE(AbstractMailMergeCreateFromDlg_Impl,SwMailMergeCreateFromDlg)
- virtual BOOL IsThisDocument() const ;
+ virtual sal_Bool IsThisDocument() const ;
};
//for SwMailMergeCreateFromDlg end
//for SwMailMergeFieldConnectionsDlg begin
@@ -347,7 +347,7 @@ class SwMailMergeFieldConnectionsDlg;
class AbstractMailMergeFieldConnectionsDlg_Impl : public AbstractMailMergeFieldConnectionsDlg
{
DECL_ABSTDLG_BASE(AbstractMailMergeFieldConnectionsDlg_Impl,SwMailMergeFieldConnectionsDlg)
- virtual BOOL IsUseExistingConnections() const ;
+ virtual sal_Bool IsUseExistingConnections() const ;
};
//for SwMailMergeFieldConnectionsDlg end
@@ -418,7 +418,7 @@ public:
virtual void SetReloadDocument(const String& rURL);
virtual const String& GetReloadDocument() const;
- virtual BOOL ShowPage( USHORT nLevel );
+ virtual sal_Bool ShowPage( sal_uInt16 nLevel );
virtual sal_uInt16 GetRestartPage() const;
};
@@ -441,7 +441,7 @@ public:
virtual AbstractSwBreakDlg * CreateSwBreakDlg ( Window *pParent, SwWrtShell &rSh,int nResId ); // add for SwBreakDlg
virtual VclAbstractDialog * CreateSwChangeDBDlg( SwView& rVw, int nResId ); //add for SwChangeDBDlg
virtual SfxAbstractTabDialog * CreateSwCharDlg( Window* pParent, SwView& pVw, const SfxItemSet& rCoreSet, int nResId, // add for SwCharDlg
- const String* pFmtStr = 0, BOOL bIsDrwTxtDlg = FALSE);
+ const String* pFmtStr = 0, sal_Bool bIsDrwTxtDlg = sal_False);
virtual AbstractSwConvertTableDlg* CreateSwConvertTableDlg ( SwView& rView, int nResId, bool bToTable ); //add for SwConvertTableDlg
virtual VclAbstractDialog * CreateSwCaptionDialog ( Window *pParent, SwView &rV,int nResId); //add for SwCaptionDialog
@@ -452,20 +452,20 @@ public:
virtual SfxAbstractTabDialog * CreateSwFootNoteOptionDlg( Window *pParent, SwWrtShell &rSh,int nResId);//add for SwFootNoteOptionDlg
virtual AbstractDropDownFieldDialog * CreateDropDownFieldDialog ( Window *pParent, SwWrtShell &rSh, //add for DropDownFieldDialog
- SwField* pField,int nResId, BOOL bNextButton = FALSE );
- virtual SfxAbstractTabDialog* CreateSwEnvDlg ( Window* pParent, const SfxItemSet& rSet, SwWrtShell* pWrtSh, Printer* pPrt, BOOL bInsert,int nResId ); //add for SwEnvDlg
+ SwField* pField,int nResId, sal_Bool bNextButton = sal_False );
+ virtual SfxAbstractTabDialog* CreateSwEnvDlg ( Window* pParent, const SfxItemSet& rSet, SwWrtShell* pWrtSh, Printer* pPrt, sal_Bool bInsert,int nResId ); //add for SwEnvDlg
virtual AbstarctSwLabDlg* CreateSwLabDlg ( Window* pParent, const SfxItemSet& rSet, //add for SwLabDlg
- SwNewDBMgr* pNewDBMgr, BOOL bLabel,int nResId );
+ SwNewDBMgr* pNewDBMgr, sal_Bool bLabel,int nResId );
virtual SwLabDlgMethod GetSwLabDlgStaticMethod (); //add for SwLabDlg
virtual SfxAbstractTabDialog* CreateSwParaDlg ( Window *pParent, //add for SwParaDlg
SwView& rVw,
const SfxItemSet& rCoreSet,
- BYTE nDialogMode,
+ sal_uInt8 nDialogMode,
int nResId,
const String *pCollName = 0,
- BOOL bDraw = FALSE,
- UINT16 nDefPage = 0);
+ sal_Bool bDraw = sal_False,
+ sal_uInt16 nDefPage = 0);
virtual AbstarctSwSelGlossaryDlg * CreateSwSelGlossaryDlg ( Window * pParent, const String &rShortName, int nResId ); //add for SwSelGlossaryDlg
virtual VclAbstractDialog * CreateVclAbstractDialog ( Window * pParent, SwWrtShell &rSh, int nResId ); //add for SwTableHeightDlg SwSortDlg
@@ -473,11 +473,11 @@ public:
virtual AbstractSwAutoFormatDlg * CreateSwAutoFormatDlg( Window* pParent, SwWrtShell* pShell, //add for SwAutoFormatDlg
int nResId,
- BOOL bSetAutoFmt = TRUE,
+ sal_Bool bSetAutoFmt = sal_True,
const SwTableAutoFmt* pSelFmt = 0 );
- virtual SfxAbstractDialog * CreateSwBorderDlg (Window* pParent, SfxItemSet& rSet, USHORT nType,int nResId );//add for SwBorderDlg
+ virtual SfxAbstractDialog * CreateSwBorderDlg (Window* pParent, SfxItemSet& rSet, sal_uInt16 nType,int nResId );//add for SwBorderDlg
- virtual SfxAbstractDialog * CreateSwWrapDlg ( Window* pParent, SfxItemSet& rSet, SwWrtShell* pSh, BOOL bDrawMode, int nResId ); //add for SwWrapDlg
+ virtual SfxAbstractDialog * CreateSwWrapDlg ( Window* pParent, SfxItemSet& rSet, SwWrtShell* pSh, sal_Bool bDrawMode, int nResId ); //add for SwWrapDlg
virtual VclAbstractDialog * CreateSwTableWidthDlg ( Window *pParent, SwTableFUNC &rFnc , int nResId ); //add for SwTableWidthDlg
virtual SfxAbstractTabDialog* CreateSwTableTabDlg( Window* pParent, SfxItemPool& Pool,
const SfxItemSet* pItemSet, SwWrtShell* pSh,int nResId ); //add for SwTableTabDlg
@@ -489,33 +489,33 @@ public:
virtual AbstractSwModalRedlineAcceptDlg * CreateSwModalRedlineAcceptDlg ( Window *pParent, int nResId ); //add for SwModalRedlineAcceptDlg
virtual VclAbstractDialog* CreateSwVclDialog( int nResId,
- Window* pParent, BOOL& rWithPrev ); //add for SwMergeTblDlg
+ Window* pParent, sal_Bool& rWithPrev ); //add for SwMergeTblDlg
virtual SfxAbstractTabDialog* CreateFrmTabDialog( int nResId,
SfxViewFrame *pFrame, Window *pParent,
const SfxItemSet& rCoreSet,
- BOOL bNewFrm = TRUE,
- USHORT nResType = DLG_FRM_STD,
- BOOL bFmt = FALSE,
- UINT16 nDefPage = 0,
+ sal_Bool bNewFrm = sal_True,
+ sal_uInt16 nResType = DLG_FRM_STD,
+ sal_Bool bFmt = sal_False,
+ sal_uInt16 nDefPage = 0,
const String* pFmtStr = 0); //add for SwFrmDlg
virtual SfxAbstractTabDialog* CreateTemplateDialog( int nResId,
Window* pParent,
SfxStyleSheetBase& rBase,
- USHORT nRegion,
- BOOL bColumn = FALSE,
+ sal_uInt16 nRegion,
+ sal_Bool bColumn = sal_False,
SwWrtShell* pActShell = 0,
- BOOL bNew = FALSE ); //add for SwTemplateDlg
+ sal_Bool bNew = sal_False ); //add for SwTemplateDlg
virtual AbstractGlossaryDlg* CreateGlossaryDlg( int nResId,
SfxViewFrame* pViewFrame,
SwGlossaryHdl* pGlosHdl,
SwWrtShell *pWrtShell); //add for SwGlossaryDlg
virtual AbstractFldInputDlg* CreateFldInputDlg( int nResId,
Window *pParent, SwWrtShell &rSh,
- SwField* pField, BOOL bNextButton = FALSE ); //add for SwFldInputDlg
+ SwField* pField, sal_Bool bNextButton = sal_False ); //add for SwFldInputDlg
virtual AbstractInsFootNoteDlg* CreateInsFootNoteDlg( int nResId,
- Window * pParent, SwWrtShell &rSh, BOOL bEd = FALSE); //add for SwInsFootNoteDlg
+ Window * pParent, SwWrtShell &rSh, sal_Bool bEd = sal_False); //add for SwInsFootNoteDlg
virtual VclAbstractDialog * CreateVclSwViewDialog( int nResId,
- SwView& rView, BOOL bCol = FALSE ); //add for SwInsRowColDlg, SwLineNumberingDlg
+ SwView& rView, sal_Bool bCol = sal_False ); //add for SwInsRowColDlg, SwLineNumberingDlg
virtual AbstractInsertGrfRulerDlg* CreateInsertGrfRulerDlg( int nResId,
Window * pParent ); //add for SwInsertGrfRulerDlg
virtual AbstractInsTableDlg* CreateInsTableDlg( int nResId,
@@ -542,8 +542,8 @@ public:
virtual AbstractMultiTOXTabDialog* CreateMultiTOXTabDialog( int nResId,
Window* pParent, const SfxItemSet& rSet,
SwWrtShell &rShell,
- SwTOXBase* pCurTOX, USHORT nToxType = USHRT_MAX,
- BOOL bGlobal = FALSE); //add for SwMultiTOXTabDialog
+ SwTOXBase* pCurTOX, sal_uInt16 nToxType = USHRT_MAX,
+ sal_Bool bGlobal = sal_False); //add for SwMultiTOXTabDialog
virtual AbstractEditRegionDlg* CreateEditRegionDlg( int nResId,
Window* pParent, SwWrtShell& rWrtSh ); //add for SwEditRegionDlg
virtual AbstractInsertSectionTabDialog* CreateInsertSectionTabDialog( int nResId,
@@ -566,13 +566,13 @@ public:
virtual AbstractMailMergeWizard* CreateMailMergeWizard(SwView& rView, SwMailMergeConfigItem& rConfigItem);
//add for static func in SwGlossaryDlg
- virtual GlossaryGetCurrGroup GetGlossaryCurrGroupFunc( USHORT nId );
- virtual GlossarySetActGroup SetGlossaryActGroupFunc( USHORT nId );
+ virtual GlossaryGetCurrGroup GetGlossaryCurrGroupFunc( sal_uInt16 nId );
+ virtual GlossarySetActGroup SetGlossaryActGroupFunc( sal_uInt16 nId );
// For TabPage
- virtual CreateTabPage GetTabPageCreatorFunc( USHORT nId );
+ virtual CreateTabPage GetTabPageCreatorFunc( sal_uInt16 nId );
- virtual GetTabPageRanges GetTabPageRangesFunc( USHORT nId );
+ virtual GetTabPageRanges GetTabPageRangesFunc( sal_uInt16 nId );
};
@@ -64,7 +64,7 @@ public: \
virtual ~Class(); \
virtual short Execute() ;
-// virtual void Show( BOOL bVisible = TRUE, USHORT nFlags = 0 )
+// virtual void Show( sal_Bool bVisible = sal_True, sal_uInt16 nFlags = 0 )
#define IMPL_ABSTDLG_BASE(Class) \
Class::~Class() \